<?php

class Action_Connect extends Action_Common
{
	private $host;
	private $login;
	private $passwd;
	private $session;

	function __construct()
	{
		$opts = getCmdOptions();
		$path = $opts->get_path_opts();

		$this->login         = $path['login'];
		$this->passwd        = $path['passwd'];
		$this->host          = $path['host'];
		$this->port          = $path['port'];
		$this->ssh_pub_key   = $path['ssh_pub_key'];
		$this->ssh_priv_key = $path['ssh_priv_key'];

		return $this;
	}

	private function open_session()
	{
		$session = ssh2_connect($this->host, $this->port);
		if (!$session)
                        throw new Mirror_Exception("Unable to connect to host '" . $this->host . ":" . $this->port . "'");

		if (!ssh2_auth_password($session, $this->login, $this->passwd)) {
			if (!ssh2_auth_pubkey_file($session, $this->login, $this->ssh_pub_key, $this->ssh_priv_key))
				throw new Mirror_Exception("Authentication error for '" . $this->login . "@" . $this->host . ":" . $this->port . "'");
		}

		$this->session = $session;
	}

	public function upload($srcfile, $dstfile, $mode)
	{
		if (empty($srcfile) || empty($dstfile) || empty($mode))
			throw new Mirror_Cmd_Exception("Invalid arguments for upload file");

		$this->open_session();

		$sftp = ssh2_sftp($this->session);
		$stream = @fopen("ssh2.sftp://$sftp/$dstfile", 'w');
		if (!$stream)
			throw new Mirror_Exception("Could not open destination file: $dstfile");

		$data_to_send = @file_get_contents($srcfile);
		if ($data_to_send === false)
			throw new Mirror_Exception("Could not open source file: $srcfile.");

		if (@fwrite($stream, $data_to_send) === false)
			throw new Exception("Could not send data from file: $srcfile");

		@fclose($stream);
	}

	public function download($srcfile, $dstfile, $mode)
	{
		if (empty($srcfile) || empty($dstfile) || empty($mode))
			throw new Mirror_Cmd_Exception("Invalid arguments for download file");

		$this->open_session();

		if (!ssh2_scp_recv($this->session, $srcfile, $dstfile))
			throw new Mirror_Exception("Unable to download file '$srcfile'");

		chmod($dstfile, $mode);
	}

	public function exec($cmd)
	{
		if (empty($cmd))
			throw new Mirror_Exception("Invalid arguments for remote execution");

		$this->open_session();

		$stdio  = ssh2_exec($this->session, $cmd);
		$stderr = ssh2_fetch_stream($stdio, SSH2_STREAM_STDERR);

		stream_set_blocking($stdio, true);
		while ($line = fgets($stdio)) {
                         flush();
                         echo $line;
                }

		stream_set_blocking($stderr, true);
		while ($line = fgets($stderr)) {
                         flush();
                         echo $line;
                }

		fclose($stdio);
		fclose($stderr);
	}
}
