<?php

define("PROGNAME", 'mirrorctl');

require_once("lib/Options.php");
require_once("lib/Types.php");
require_once("lib/Exception.php");
require_once("lib/Common.php");
require_once("lib/Usage.php");
require_once("lib/CmdOptions.php");
require_once("lib/Action.php");
require_once("lib/Product.php");
require_once("lib/Config.php");
require_once("lib/Sync.php");
require_once("lib/Bootstrap.php");

try {
	check_php_components();
	main($argc, $argv);
} catch (Mirror_Cmd_Exception $e) {
	echo "\n" . $e->getMessage() . "\n\n";
	echo "Usage: '" . PROGNAME . " help' for details\n";
	exit(1);
} catch (Mirror_Boot_Exception $e) {
	echo "\nSome components/options are required for normal working this tool:\n";
	echo "    ---> " . $e->getMessage() . "\n\n";
	echo "Please install it first\n";
} catch (Mirror_Config_Exception $e) {
	echo "ERROR: Configuration is wrong:\n     " . $e->getMessage() . "\n";
	exit(1);
} catch (Mirror_Exception $e) {
	echo "ERROR: " . $e->getMessage() . "\n";
	exit(1);
} catch (Exception $e) {
	echo "Unknown error: " . $e->getMessage() . "\n";
	exit(1);
}

exit(0);

function main($argc, $argv) {
	global $options;

	create_tmp_dir();

	$opts = getCmdOptions($argc, $argv);
	switch ($opts->get_cmd()) {
		case Types::PRODUCT_LST:
		case Types::SHOW_RELEASES:
			$product = Product::factory(Types::PLESK);
			$rels = $product->get_release_list();

			echo "Follow releases are acessible:\n";
			foreach ($rels AS $rel)
				echo "    " . $rel . "\n";
			break;

		case Types::OS_LST:
			if (!$opts->get_release())
				throw new Mirror_Cmd_Exception("Option --release is not defined");

			$product = Product::factory(Types::PLESK);
			$oses = $product->get_os_list($opts->get_release());

			echo "Follow operaing systems are acessible for release " . $opts->get_release() . ":\n";
			foreach ($oses AS $os) {
				echo "    " . $os . "\n";
			}
			break;

		case Types::CFG:
			$cfg = new Config($opts->get_cfg_file());
			if ($opts->is_set(Types::CHECK))
				$cfg->check();

			if ($opts->is_set(Types::ADD)) {
				$cfg->add($opts->get_release(), $opts->get_os());
				break;
			}
			if ($opts->is_set(Types::REMOVE)) {
				$cfg->remove($opts->get_release(), $opts->get_os());
				break;
			}
			if ($opts->is_set(Types::IMPORT)) {
				$cfg->import();
				break;
			}
			if ($opts->is_set(Types::EXPORT)) {
				$cfg->export();
				break;
			}
			break;

		case Types::UPDATE:
			$update = Sync::factory(Types::SYNC_UP);
			$update->update();
			break;

		case Types::PUSH:
			$push = Sync::factory(Types::SYNC_PH);
			$push->update();
			break;

		case Types::DESTROY:
			break;

		case Types::VERSION:
			print_version(PROGNAME);
			break;

		case Types::HELP:
		default:
			usage(PROGNAME);
			exit(0);
	}
}
